<?php
namespace PME\Controllers\Custo;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class CustoCardapioMesController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $birtStrategy;
    protected $environment;
    protected $utilities;
    protected $connection;

    public function __construct(ReportService $reportService, $entityManager, $birtStrategy, $environment, $utilities, $connection) {
        $this->entityManager = $entityManager;
        $this->birtStrategy  = $birtStrategy;
        $this->environment   = $environment;
        $this->utilities     = $utilities;
        $this->connection    = $connection;
        
        parent::__construct($reportService);
    }

    protected $reportMapping = array (
      'PME08200' => 
      array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
        array (
          "CDTIPOCUSTO"  => "P_CDTIPOCUSTO",
          "NMTIPOCUSTO"  => "P_NMTIPOCUSTO",
          "DTINI"        => "P_DTINICIAL",
          "DTFIN"        => "P_DTFINAL",
          "DTINICONSPLAN" => "P_DTINICONSPLAN",
          "DTFINCONSPLAN" => "P_DTFINCONSPLAN",
          "CDFILCENTPME" => "P_CDFILCENTPME",
          "NMFILCENTPME" => "P_NMFILCENTPME",
          "CDTIPOCARD"   => "P_CDTIPOCARD",
          "NMTIPOCARD"   => "P_NMTIPOCARD",
          "CDSERVFILI"   => "P_CDSERVFILI",
          "NRCONSPLAN"   => "P_NRCONSPLAN",
          "NMFILIAGRE"   => "P_NMFILIAGRE",
          "CDFILIAGRE"   => "P_CDFILIAGRE",
          "NRORG"        => "P_NRORG",
        )
      ),
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
      $row = $request->getRow();
      
      $nrorg = $this->environment->getNrOrgTrab();
      $row['NRORG'] = $nrorg;
      
      if(empty($row['SERVICO'])) $servico = $this->getServicos($row);
      else $servico = is_array($row['CDSERVFILI']) ? join("_", $row['CDSERVFILI']) : $row['CDSERVFILI'];
      
      $row['CDSERVFILI'] = $servico;
      $row['NRCONSPLAN'] = $this->utilities->consumoPlanPMe($row['CDFILCENTPME'], $row['CDTIPOCARD'], $row['CDFILIAGRE'], $row['CDSERVFILI'], $row['DTINICONSPLAN'], $row['DTFINCONSPLAN'], 'A', 'CFP', 'P');
      
      $this->birtStrategy->setReportLocale($this->environment->getLanguage());
      $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
    }
    
    private function getServicos($row){
      $nrorg = $this->environment->getNrOrgTrab();
      $servicos = [];
      
      $query = "SELECT ST.CDTIPOCARD, ST.CDFILCENTPME, ST.CDSERVFILI, S.NMSERVICO, ST.CDSERVFILI || ' - ' || S.NMSERVICO AS DESCRICAO, S.NRORG 
                FROM SERVTIPOCARD ST INNER JOIN SERVICO S ON S.NRORG = ST.NRORG AND S.CDFILIAL = ST.CDFILCENTPME AND S.CDSERVFILI = ST.CDSERVFILI AND S.IDTIPOSERV = 'M' 
                WHERE ST.NRORG = :NRORG AND ST.CDFILCENTPME = :CDFILCENTPME AND (INSTR(NVL(:CDTIPOCARD,ST.CDTIPOCARD), ST.CDTIPOCARD) > 0) ORDER BY ST.CDSERVFILI";
      $params = array(
        "CDFILCENTPME" => $row["CDFILCENTPME"],
        "CDTIPOCARD"   => $row["CDTIPOCARD"],
        "NRORG"        => $nrorg
      );
      $stmt = $this->connection->prepare($query);
		  $stmt->execute($params);
      $result = $stmt->fetchAll();
      
      foreach($result as $serv){
        array_push($servicos, $serv['CDSERVFILI']);
      }
      
      $resultado = join("_", $servicos);
      return $resultado;
    }
}