<?php
namespace PME\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;

class Lista extends \PME\Services\TeknisaCrud {

    protected $dataSourceName = "lista";
    protected $entityManager;
    protected $novoCodigo;


    public function __construct(
        $crudService, $parameterBag,
        $entityManager,
        $novoCodigo
    ) {
        $this->entityManager = $entityManager;
        $this->novoCodigo = $novoCodigo;
        parent::__construct($crudService, $parameterBag);
    }

    public function geraLista($cdlista, $nrorg){
        $rows = explode("_", $cdlista);
        
        $dataSourceName = 'lista';
        $nrlista = $this->novoCodigo->getCodeByTableName($dataSourceName, $nrorg);

        $registros = array();
        foreach ($rows as $row) {
            if(!empty($row)){
                $row = array(
                    "NRLISTA"  => $nrlista,
                    "CDLISTA"  => $row,
                    "__is_new" => true,
                    "NRORG"    => $nrorg
                );
                array_push($registros, $row);
            }
        }
        
        $dataSet = new DataSet($dataSourceName, $registros);
        $request = new DTO\Request\DataSet($dataSet, "", "", "");
        $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);
        $newRows = [];
        if(!empty($rowsToSave)){
            foreach($rowsToSave as $row){
                if(!array_key_exists('DTULTATULIST', $row)) $row['DTULTATULIST'] = $row['DTULTATU'];
                array_push($newRows, $row);
            }
        }
        
        $this->crudService->save($dataSourceName, $newRows);
        
        return $nrlista;
    }
    
    public function insereListaProduto(DTO\Request $request, DTO\Response $response){
        $parametros = $request->getRow();
        $cdlista = $parametros['CDLISTA'];
        $nrorg = $parametros['NRORG'];
        
        $nrlista = $this->geraLista($cdlista, $nrorg);
        
        $response->addDataSet(new DataSet ('LISTAPRODUTO', array('LISTA' => $nrlista)));
    }
    
    public function insereListaServico(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $nrlistaServico = $this->geraListaServico($row['FILISERV'], $row['NRORG']);
        $response->addDataSet(
            new DataSet ('NRLISTASERVICO', array('NRLISTASERVICO' => $nrlistaServico))
        );
    }
    
    public function geraListaServico($filiserv, $nrorg){
        $servicosFiliais = explode("_",$filiserv);
        
        $nrlistaServico = $this->novoCodigo->getCodeByTableName('LISTA_SERVICO', $nrorg);
        
        $sql = "INSERT INTO LISTA_SERVICO (NRLISTA, CDFILIAL, CDSERVFILI, NMSERVICO, CDGRUPSERV, NRORG) VALUES (:NRLISTA, :CDFILIAL, :CDSERVFILI, :NMSERVICO, :CDGRUPSERV, :NRORG)";
        
        foreach ($servicosFiliais as $servicoFilial) {
            if(!empty($servicoFilial)){
                $servicoFilial = $this->infoServico($servicoFilial);
                
                $stmt = $this->entityManager->getConnection()->prepare($sql);
                $stmt->execute(
                    array(
                        "NRLISTA" => $nrlistaServico,
                        "CDFILIAL" => $servicoFilial['CDFILIAL'],
                        "NRORG" => $nrorg,
                        "CDSERVFILI" => $servicoFilial['CDSERVFILI'],
                        "NMSERVICO" => $servicoFilial['NMSERVICO'],
                        "CDGRUPSERV" => $servicoFilial['CDGRUPSERV']
                    )
                );
                
            }
            
        }
        
        return $nrlistaServico;
    }
    
    private function infoServico($row){
        $cdfilial = substr($row,0,4);
        $cdservfili = substr($row,4,5);
        $sql = "SELECT S.CDFILIAL, S.CDSERVFILI,S.NMSERVICO, G.CDGRUPSERV FROM SERVICO S
                    INNER JOIN GRUPSERV G ON G.CDGRUPSERV = S.CDGRUPSERV
                WHERE S.CDFILIAL =:CDFILIAL AND S.CDSERVFILI =:CDSERVFILI";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "CDFILIAL"   => $cdfilial,
                "CDSERVFILI"  => $cdservfili
            )
        );
        $result = $stmt->fetchAll(\PDO::FETCH_ASSOC);
        return $result[0];
    }
}